@@ -123,6 +123,8 @@ var (
 		"equinix-metal": "Equinix Metal",
 		"splunk":        "Splunk",
 		"yandex":        "Yandex",
+		"rke":           "Rancher RKE",
+		"sumologic":     "SumoLogic",
 	}
 	// Property anchor tag separator, used in a property anchor tag id to separate the
 	// property and language (e.g. property~lang).
